@@ -6,7 +6,7 @@ use utf8;
 package Marlin;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.011001';
+our $VERSION   = '0.011002';
 
 use constant _ATTRS => qw( caller this parents roles attributes strict constructor modifiers inhaled_from short_name is_struct plugins setup_steps_with_plugins delayed );
 use B::Hooks::AtRuntime   ();
@@ -603,7 +603,7 @@ sub setup_roles {
 		} @{ $me->roles }
 	) or return $me;
 	
-	my ( $is_moose_role, $is_mouse_role, $is_op_role );
+	my ( $is_moose_role, $is_mouse_role );
 	if ( $INC{'Moose/Role.pm'} ) {
 		$is_moose_role = sub {
 			require Moose::Util;
@@ -619,7 +619,7 @@ sub setup_roles {
 		};
 	}
 
-	my ( @moose_roles, @mouse_roles, @op_roles, @tiny_roles );
+	my ( @moose_roles, @mouse_roles, @tiny_roles );
 	for my $r ( @roles ) {
 		if ( $is_moose_role and $is_moose_role->($r) ) {
 			push @moose_roles, $r;
@@ -758,13 +758,7 @@ sub setup_imports {
 	
 	my @imports;
 	if ( $me->modifiers ) {
-		require Class::Method::Modifiers;
-		push @imports, (
-			before => \&Class::Method::Modifiers::before,
-			after  => \&Class::Method::Modifiers::after,
-			around => \&Class::Method::Modifiers::around,
-			fresh  => \&Class::Method::Modifiers::fresh,
-		);
+		push @imports, $me->_make_modifier_imports;
 	}
 	
 	$me->lexport( @imports );
@@ -772,6 +766,16 @@ sub setup_imports {
 	return $me;
 }
 
+sub _make_modifier_imports {
+	require Class::Method::Modifiers;
+	return (
+		before => \&Class::Method::Modifiers::before,
+		after  => \&Class::Method::Modifiers::after,
+		around => \&Class::Method::Modifiers::around,
+		fresh  => \&Class::Method::Modifiers::fresh,
+	);
+}
+
 sub export {
 	my $me = shift;
 	my $pkg = $me->this;
